@@ -1,10 +1,12 @@
-# EB.pm -- 
-# RCS Info        : $Id$
+#! perl
+
+# EB.pm -- EekBoek Base module.
+# RCS Info        : $Id: EB.pm,v 1.86 2008/03/22 15:54:57 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Fri Sep 16 18:38:45 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Fri Feb  2 11:11:51 2007
-# Update Count    : 204
+# Last Modified On: Sat Mar 22 16:45:55 2008
+# Update Count    : 219
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -14,12 +16,12 @@ our $cfg;
 
 package EB;
 
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.86 $ =~ /(\d+)/g;
+
 use strict;
 use base qw(Exporter);
 
-our $VERSION = $EekBoek::VERSION;
 use EekBoek;
-BEGIN { $VERSION = $EekBoek::VERSION }
 
 our @EXPORT;
 our @EXPORT_OK;
@@ -39,12 +41,15 @@ sub EB_LIB() { $lib }
 # Some standard modules.
 use EB::Globals;
 use Carp;
+use EB::Assert;
 use Data::Dumper;
 
 BEGIN {
     # The core and GUI use a different EB::Locale module.
     if ( $app ) {
 	require EB::Wx::Locale;
+	# Force UNICODE for Wx.
+	$cfg->newval(qw(locale unicode), 1);
     }
     else {
 	require EB::Locale;
@@ -64,6 +69,7 @@ BEGIN {
 		qw(carp croak),
 		qw(Dumper),
 		qw(findlib),
+		qw(assert affirm),
 	      );
 }
 
@@ -72,6 +78,7 @@ our @month_names;
 our @days;
 our @day_names;
 our $ident;
+our $imsg;
 our $url = "http://www.eekboek.nl";
 
 # Most elegant (and correct) would be to use an INIT block here, but
@@ -89,15 +96,16 @@ INIT {
     my @locextra;
     push(@locextra, _T("Nederlands")) if LOCALISER;
     push(@locextra, "Latin1") unless $cfg->val(qw(locale unicode), 0);
-    warn(__x("{ident}{extra}{locale} -- Copyright {year} Squirrel Consultancy",
-		 ident   => $ident,
-		 extra   => ($app ? " Wx " : ""),
-		 locale  => (@locextra ? " (".join(", ", @locextra).")" : ""),
-		 year    => $year)."\n") unless @ARGV && $ARGV[0] =~ /-(P|-?printcfg)$/;
+    $imsg = __x("{ident}{extra}{locale} -- Copyright {year} Squirrel Consultancy",
+		ident   => $ident,
+		extra   => ($app ? " Wx " : ""),
+		locale  => (@locextra ? " (".join(", ", @locextra).")" : ""),
+		year    => $year);
+    warn($imsg, "\n") unless @ARGV && $ARGV[0] =~ /-(P|-?printcfg)$/;
 
     eval {
 	require Win32;
-	my @a = Win32::GetOSVersion(); 
+	my @a = Win32::GetOSVersion();
 	my ($id, $major) = @a[4,1];
 	die unless defined $id;
 	warn(_T("EekBoek is VRIJE software, ontwikkeld om vrij over uw eigen gegevens te kunnen beschikken.")."\n");
@@ -108,7 +116,7 @@ INIT {
 	    $incompatibleOS++;
 	    warn(_T("Dit is niet te verenigen met uw keuze voor dit Microsoft Windows besturingssysteem.")."\n");
 	}
-    };
+    } unless $ENV{AUTOMATED_TESTING};
 
     @months =
       split(" ", _T("Jan Feb Mrt Apr Mei Jun Jul Aug Sep Okt Nov Dec"));
@@ -150,7 +158,7 @@ appreciated).
 
 =head1 DESCRIPTION
 
-For a description how to use the program, see L<http://www.squirrel.nl/eekboek/docs/index.html>.
+For a description how to use the program, see L<http://www.eekboek.nl/docs/index.html>.
 
 =head1 BUGS AND PROBLEMS
 
@@ -164,7 +172,7 @@ Web site: L<http://www.eekboek.nl>.
 
 =head1 COPYRIGHT AND DISCLAIMER
 
-This program is Copyright 2005-2007 by Squirrel Consultancy. All
+This program is Copyright 2005-2008 by Squirrel Consultancy. All
 rights reserved.
 
 This program is free software; you can redistribute it and/or modify
