@@ -1,21 +1,28 @@
-# Config.pm -- 
-# RCS Info        : $Id$
+#! perl
+
+# Config.pm -- Configuration files.
+# RCS Info        : $Id: Config.pm,v 1.14 2008/02/18 10:31:19 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Fri Jan 20 17:57:13 2006
 # Last Modified By: Johan Vromans
-# Last Modified On: Wed Dec 13 21:44:06 2006
-# Update Count    : 76
+# Last Modified On: Mon Feb 18 11:07:50 2008
+# Update Count    : 88
 # Status          : Unknown, Use with caution!
 
 package main;
 
 our $cfg;
+our $dbh;
 
 package EB::Config;
 
 use strict;
 use warnings;
+
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.14 $ =~ /(\d+)/g;
+
 use EB::Config::IniFiles;
+use File::Spec;
 
 my $unicode;
 
@@ -60,6 +67,15 @@ sub init_config {
 	if ( !defined($dir) ) {
 	    last unless $extraconf;
 	    $file = $extraconf;
+	    if ( -d $file ) {
+		my $f = File::Spec->catfile($file, "$app.conf");
+		if ( -e $f ) {
+		    $file = $f;
+		}
+		else {
+		    $file = File::Spec->catfile($file, ".$app.conf");
+		}
+	    }
 	    die("$file: $!\n") unless -f $file;
 	}
 	else {
@@ -81,6 +97,20 @@ sub init_config {
     # Make sure we have an object, even if no config files.
     $cfg ||= EB::Config::IniFiles::Wrapper->new;
 
+    $i = 0;
+    while ( $i < @ARGV ) {
+	if ( $ARGV[$i] eq "-D" &&
+	     $i+1 < @ARGV && $ARGV[$i+1] =~ /^(\w+(?:::\w+)*)::?(\w+)=(.*)/ ) {
+	    $cfg->newval($1, $2, $3);
+	    splice(@ARGV, $i, 2);
+	}
+	elsif ( $ARGV[$i] =~ /^--define=(\w+(?:::\w+)*)::?(\w+)=(.*)/ ) {
+	    $cfg->newval($1, $2, $3);
+	    splice(@ARGV, $i, 1);
+	}
+	$i++;
+    }
+
     $ENV{EB_LANG} = $cfg->val('locale','lang',
 			      $ENV{EB_LANG}||$ENV{LANG}||
 			      ($^O =~ /^(ms)?win/i ? "nl_NL.utf8" : "nl_NL"));
